API docs for “spamfighter.core.commands.command.ICommand”

# Class s.c.c.c.ICommand(Interface):

Part of spamfighter.core.commands.command View Source View In Hierarchy

Интерфейс команд. Этот интерфейс обязаны реализовывать все наследники Command.

Method | perform | Выполнить команду. Выполняет действия по вычислению результата

def perform(self): (source)
Выполнить команду. Выполняет действия по вычислению результата команды. Перед вызовом проверяется наличие всех обязательных параметров.

Returns | Deferred, которая вызывается после завершения вычисления команды. Если команда была успешна, то в массив `result` команды должен быть записан результат. (type: `twisted.internet.defer.Deferred` )